@@ -141,7 +141,7 @@ class Yhat(API):
                     source = inspect.getsource(udf).split("\n")
                     padding = re.search('[ ]+', source[0]).group(0)
                     for line in source:
-                        filesource += line[len(padding):] + "\n"
+                        filesource += line[len(padding)-1:] + "\n"
                     filesource += "\n"
         filesource += "#<end user functions>\n"
 
